pub fn scope_blocks(blocks: &Value) -> Vec<Value>
Return the prefix of blocks up to and including the LAST cache_control marker. If no marker is present, the full list is returned. Non-arrays produce an empty list.
blocks
cache_control